==> ejc-riskmortgage-impl-3.0.0-20220711.021151-42-sources.jar: com/ejianc/business/standard/bean/StandardRecordDetailEntity.java <==
package com.ejianc.business.standard.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险金缴纳标准记录表子实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_standard_record_detail")
public class StandardRecordDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_id")
    private Long projectId; // 所属项目Id
    @TableField(value="project_name")
    private String projectName; // 所属项目名称
    @TableField(value="project_code")
    private String projectCode; // 所属项目编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编码
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同金额
    @TableField(value="start_date")
    private Date startDate; // 开工日期
    @TableField(value="finish_date")
    private Date finishDate; // 竣工日期
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="record_id")
    private Long recordId; // 记录表ID-pid
    @TableField(value="standard_id")
    private Long standardId; // 风险保证金主键
    @TableField(value="src_table_id")
    private Long srcTableId; // 来源主合同子表id
    
    
    

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getFinishDate() {
        return finishDate;
    }

    public void setFinishDate(Date finishDate) {
        this.finishDate = finishDate;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public Long getStandardId() {
        return standardId;
    }

    public void setStandardId(Long standardId) {
        this.standardId = standardId;
    }
    public Long getSrcTableId() {
        return srcTableId;
    }

    public void setSrcTableId(Long srcTableId) {
        this.srcTableId = srcTableId;
    }
    
}

==> ejc-riskmortgage-impl-3.0.0-20231205.095049-100-sources.jar: com/ejianc/business/standard/bean/StandardRecordDetailEntity.java <==
package com.ejianc.business.standard.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险金缴纳标准记录表子实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_standard_record_detail")
public class StandardRecordDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_id")
    private Long projectId; // 所属项目Id
    @TableField(value="project_name")
    private String projectName; // 所属项目名称
    @TableField(value="project_code")
    private String projectCode; // 所属项目编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编码
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同金额
    @TableField(value="start_date")
    private Date startDate; // 开工日期
    @TableField(value="finish_date")
    private Date finishDate; // 竣工日期
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="record_id")
    private Long recordId; // 记录表ID-pid
    @TableField(value="standard_id")
    private Long standardId; // 风险保证金主键
    @TableField(value="src_table_id")
    private Long srcTableId; // 来源主合同子表id

    @TableField(value="project_parent_org_id")
    private Long projectParentOrgId; //所属项目父组织Id
    @TableField(value="project_parent_org_name")
    private String projectParentOrgName; //所属项目父组织名称
    @TableField(value="project_parent_org_code")
    private String projectParentOrgCode; //所属项目父组织编码
    
    

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getFinishDate() {
        return finishDate;
    }

    public void setFinishDate(Date finishDate) {
        this.finishDate = finishDate;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public Long getStandardId() {
        return standardId;
    }

    public void setStandardId(Long standardId) {
        this.standardId = standardId;
    }
    public Long getSrcTableId() {
        return srcTableId;
    }

    public void setSrcTableId(Long srcTableId) {
        this.srcTableId = srcTableId;
    }

    public Long getProjectParentOrgId() {
        return projectParentOrgId;
    }

    public void setProjectParentOrgId(Long projectParentOrgId) {
        this.projectParentOrgId = projectParentOrgId;
    }

    public String getProjectParentOrgName() {
        return projectParentOrgName;
    }

    public void setProjectParentOrgName(String projectParentOrgName) {
        this.projectParentOrgName = projectParentOrgName;
    }

    public String getProjectParentOrgCode() {
        return projectParentOrgCode;
    }

    public void setProjectParentOrgCode(String projectParentOrgCode) {
        this.projectParentOrgCode = projectParentOrgCode;
    }
}
